@@ -4,7 +4,7 @@ use warnings;
 
 package Data::Storage::DBI::Mock;
 BEGIN {
-  $Data::Storage::DBI::Mock::VERSION = '1.102520';
+  $Data::Storage::DBI::Mock::VERSION = '1.102720';
 }
 # ABSTRACT: Base class for mock DBI storages
 use parent 'Data::Storage::Mock';
@@ -31,7 +31,7 @@ Data::Storage::DBI::Mock - Base class for mock DBI storages
 
 =head1 VERSION
 
-version 1.102520
+version 1.102720
 
 =head1 METHODS
 
@@ -48,7 +48,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
 
 =head1 AVAILABILITY
 
