@@ -4,7 +4,7 @@ use warnings;
 
 package Data::Storage::DBI::Unrealized;
 BEGIN {
-  $Data::Storage::DBI::Unrealized::VERSION = '1.102520';
+  $Data::Storage::DBI::Unrealized::VERSION = '1.102720';
 }
 # ABSTRACT: Proxy class for lazy DBI connections
 use parent 'Class::Accessor::Complex';
@@ -32,7 +32,7 @@ Data::Storage::DBI::Unrealized - Proxy class for lazy DBI connections
 
 =head1 VERSION
 
-version 1.102520
+version 1.102720
 
 =head1 INSTALLATION
 
@@ -43,7 +43,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
 
 =head1 AVAILABILITY
 
