@@ -4,7 +4,7 @@ use warnings;
 
 package Data::Storage::DBIC;
 BEGIN {
-  $Data::Storage::DBIC::VERSION = '1.102520';
+  $Data::Storage::DBIC::VERSION = '1.102720';
 }
 # ABSTRACT: Base class for DBIx::Class-based storages
 use Error::Hierarchy::Util qw(assert_defined load_class);
@@ -102,7 +102,7 @@ Data::Storage::DBIC - Base class for DBIx::Class-based storages
 
 =head1 VERSION
 
-version 1.102520
+version 1.102720
 
 =head1 METHODS
 
@@ -139,7 +139,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
 
 =head1 AVAILABILITY
 
