@@ -4,7 +4,7 @@ use warnings;
 
 package Data::Storage::Exception;
 BEGIN {
-  $Data::Storage::Exception::VERSION = '1.102520';
+  $Data::Storage::Exception::VERSION = '1.102720';
 }
 # ABSTRACT: Base class for storage exceptions
 use parent qw(Error::Hierarchy Class::Accessor::Complex);
@@ -20,7 +20,7 @@ Data::Storage::Exception - Base class for storage exceptions
 
 =head1 VERSION
 
-version 1.102520
+version 1.102720
 
 =head1 INSTALLATION
 
@@ -31,7 +31,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
 
 =head1 AVAILABILITY
 
