@@ -4,7 +4,7 @@ use warnings;
 
 package Data::Storage::Memory;
 BEGIN {
-  $Data::Storage::Memory::VERSION = '1.102520';
+  $Data::Storage::Memory::VERSION = '1.102720';
 }
 # ABSTRACT: Base class for memory-based storages
 use parent 'Data::Storage';
@@ -32,7 +32,7 @@ Data::Storage::Memory - Base class for memory-based storages
 
 =head1 VERSION
 
-version 1.102520
+version 1.102720
 
 =head1 METHODS
 
@@ -65,7 +65,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
 
 =head1 AVAILABILITY
 
