@@ -4,7 +4,7 @@ use warnings;
 
 package Data::Storage::Null;
 BEGIN {
-  $Data::Storage::Null::VERSION = '1.102520';
+  $Data::Storage::Null::VERSION = '1.102720';
 }
 # ABSTRACT: Base class for null storages
 use Class::Null;
@@ -27,7 +27,7 @@ Data::Storage::Null - Base class for null storages
 
 =head1 VERSION
 
-version 1.102520
+version 1.102720
 
 =head1 METHODS
 
@@ -48,7 +48,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
 
 =head1 AVAILABILITY
 
